<!--
 * @Author: your name
 * @Date: 2022-02-05 00:15:52
 * @LastEditTime: 2022-02-28 14:09:40
 * @LastEditors: Please set LastEditors
 * @Description: 打开koroFileHeader查看配置 进行设置: https://github.com/OBKoro1/koro1FileHeader/wiki/%E9%85%8D%E7%BD%AE
 * @FilePath: \PyPackage\cjen\README.md
-->

公司使用内部工具类

- 1.0.5 加入第一版脚手架
- 1.0.8.2 修改了内置的url
- 1.0.8.9 提供了一步创建sponsor,study,site的工具类